@@ -35,6 +35,8 @@ AptInterface::AptInterface(MainWindow* w_)
 	iMode = ModeNone;
 	iReady = false;
 	iError = tr("Undefined error");
+
+	getRepositories();
 }
 
 AptInterface::~AptInterface()
@@ -143,6 +145,9 @@ void AptInterface::procFinished(int exitCode, QProcess::ExitStatus exitStatus)
 				iMainWindow->operationFinished(lastMode, false, "<b>Could not resolve host</b><br>" \
 											   "Some (or all) of the catalogs might be incomplete. Check your network connection");
 			} else {
+				QFile lastupdate("/root/.fapman/lastupdate");	// create empty file, access time can be used later
+				if( lastupdate.open(QIODevice::WriteOnly) )
+					lastupdate.close();
 				iMainWindow->operationFinished(lastMode, true, "");
 			}
 		}
@@ -466,8 +471,7 @@ QStringList AptInterface::getRepositories()
 			QString line = own.readLine();
 			repos.append(line.trimmed());
 		}
-		own.close();
-
+		own.close();		
 		return repos;
 	}
 
@@ -489,7 +493,7 @@ QStringList AptInterface::getRepositories()
 
 	for( int i=0; i<additional.count(); i++ )
 	{
-		if( !repos.contains( additional.at(i) ) )
+		if( !repos.contains(additional.at(i)) && !repos.contains("#"+additional.at(i)))
 		{
 			repos.append( "#" + additional.at(i) );
 		}
@@ -532,5 +536,26 @@ bool AptInterface::needRepoRefresh()
 	if( own.size() != ham.size() )
 		return true;
 
+	QFileInfo a("/root/.fapman/lastupdate");
+	QFileInfo b("/home/user/.hildon-application-manager/last-update");
+	QDateTime aDate;
+	QDateTime bDate;
+	aDate.setTime_t(0);
+	bDate.setTime_t(0);
+	if( a.exists() )
+		aDate = a.lastModified();
+	if( b.exists() )
+		bDate = b.lastModified();
+	aDate = aDate.addSecs(24*60*60); //24h
+	bDate = bDate.addSecs(24*60*60); //24h
+/*
+	std::cout
+			<< aDate.toString("dd.MM.yyyy hh:mm").toStdString() << "  "
+			<< bDate.toString("dd.MM.yyyy hh:mm").toStdString() << "  "
+			<< QDateTime::currentDateTime().toString("dd.MM.yyyy hh:mm").toStdString() << std::endl;
+*/
+	if( aDate < QDateTime::currentDateTime() && bDate < QDateTime::currentDateTime() )
+		return true;
+
 	return false;
 }
