@@ -55,6 +55,7 @@ MainWindow::MainWindow(QWidget *parent) :
 	iDimmer = new dimmer(this);
 
 	iReposAutoUpdating = false;
+	iUpgradeAutoUpdate = true;
 }
 
 MainWindow::~MainWindow()
@@ -83,7 +84,8 @@ void MainWindow::on_btnRepos_clicked()
 }
 
 void MainWindow::on_btnUpdate_clicked()
-{
+{	
+	//std::cout << "update" << std::endl;
 	busyDialog(true, tr("Operation in progress"), tr("Updating catalogs"));
 	if( !iAptInterface->updateCatalogs() )
 	{
@@ -112,7 +114,8 @@ void MainWindow::on_btnListInstallable_clicked()
 	if( iOperation != OpNone ) return;
 	iOperation = OpInstall;
 
-	if( iAptInterface->needRepoRefresh() ) {
+	if( iAptInterface->needRepoRefresh() )
+	{
 		iReposAutoUpdating = true;
 		on_btnUpdate_clicked();
 		return;
@@ -132,8 +135,10 @@ void MainWindow::on_btnUpgrade_clicked()
 	if( iOperation != OpNone ) return;
 	iOperation = OpUpgrade;
 
-	if( iAptInterface->needRepoRefresh() ) {
+	if( iAptInterface->needRepoRefresh() ) //|| iUpgradeAutoUpdate ) // this feature is disabled on purpose
+	{
 		iReposAutoUpdating = true;
+		iUpgradeAutoUpdate = false;
 		on_btnUpdate_clicked();
 		return;
 	}
@@ -145,6 +150,7 @@ void MainWindow::on_btnUpgrade_clicked()
 		d.setText("Error","<b>Unable to perform operation</b><br>Can't write repository lists");
 		d.exec();
 	}
+	iUpgradeAutoUpdate = true;
 }
 
 void MainWindow::operationFinished(AptInterface::aptMode lastMode_, bool success_, QString msg_)
@@ -239,7 +245,7 @@ void MainWindow::operationFinished(AptInterface::aptMode lastMode_, bool success
 			on_btnUpgrade_clicked();
 			return;
 		}
-	} else if( lastMode_ == AptInterface::ModeAptGetUpdate ) {
+	} else if( lastMode_ == AptInterface::ModeAptGetUpdate && success_ ) {
 		iOperation = OpNone;
 		busyDialog(false);
 		ConfirmDialog d(false, this);
