@@ -43,7 +43,6 @@ void RepoView::openWin()
 	QStringList repos = iAptInterface->getRepositories();
 
 	ui->listWidget->clear();
-	//ui->listWidget->addItems(repos);
 
 	for( int i=0; i<repos.count(); i++ )
 	{
@@ -55,6 +54,13 @@ void RepoView::openWin()
 			ui->listWidget->addItem( add );
 			ui->listWidget->item(i)->setSelected(true);
 		}
+		QSize s = ui->listWidget->item(i)->sizeHint();
+		s.setHeight(60);
+		s.setWidth(750);
+		ui->listWidget->item(i)->setSizeHint( s );
+		QFont f = ui->listWidget->item(i)->font();
+		f.setPointSize( f.pointSize()-1 );
+		ui->listWidget->item(i)->setFont(f);
 	}
 
 	show();
